version 15
#delim;
clear all ;
set more off ;
set logtype text ;
capture log close ;
set maxvar 20000 ;
set matsize 10000 ;

do "../../load_directories.do" ;
do "load_normative_directories.do" ;

log using "$output/normative_surplus_analysis.log", replace ;


/* *************************** */
/* ********* OPTIONS ********* */
/* *************************** */
/* Specification options for robustness tests and heterogeneity analysis */
local by_ed_het = 0 ;
	/* Baseline: 0 */
	/* Heterogeneity (Table F2): 1 */
local hi_type "none" ;
	/* Baseline: "none" */
	/* Robustness (Table F3): "oop", "tot", "oop_ratio_min" "tot_ratio_min" "fhl" */
local earnings_responses "baseline" ;
	/* Baseline: "baseline" */
	/* Robustness (Table F4): "severity", "multiplied_by_four" */
local crra = 2 ;    /* Coefficient of relative risk aversion */
	/* Baseline: 2 */
	/* Robustness (Table F5): 1, 3 */
local sdu "none" ;  /* State-dependent utility */
	/* Baseline: "none" */
	/* Robustness (Table F5): "lower_when_more_severe", "higher_when_more_severe" */
local markup_scaling_factor = 1 ;
	/* Baseline: 1 */
	/* Robustness (Table F5): 0.25 */
local severity_definition "baseline" ;
	/* Baseline: "baseline" */
	/* Robustness (Table H1): "plus_somewhat", "plus_mental_health" */
local risk_types_option "baseline" ;
	/* Baseline: "baseline" */
	/* Robustness (Table H2): "earnings", "estimate_markup_with_controls" */
local state_safety_net_quartile "all" ;
	/* Baseline: "all" */
	/* Robustness (Table F8): "1", "2", "3", "4" */
local discount_on_ldi_benefits = 0 ;
	/* Baseline: 0 */
	/* Robustness (stats in footnote 4): 0.35, 0.75 */
local exclude_certain_ldi_benefits = 0 ;
	/* Baseline: 0 */
	/* Robustness (stats at end of section 5.3 and end of section 5.5): 1 */


/* *************************** */
/* ****** PRELIMINARIES ****** */
/* *************************** */
local weight_str "[aweight = family_weight]" ;
local max_num_real_risk_groups = 10 ;
local missing_val_code   = . ;
local program_types "di sev_di ns_di ndi sev_ndi ns_ndi pop sev ns ad2 td2 ie ben award" ;
local risk_group_types "sbv ed z35d reg" ;
local num_risk_group_types = 4 ;
local n_tot_risk_groups_incl_agg = (1)+(4+1)+(10+1)+(1) ;

local HI_ZERO          = 0 ;
local HI_OOP           = 0 ;
local HI_TOT           = 0 ;
local HI_OOP_RATIO_MIN = 0 ;
local HI_TOT_RATIO_MIN = 0 ;
local HI_FHL_MAX       = 0 ;
if "`hi_type'" == "none" { ;
	local HI_ZERO = 1 ;
} ;
else if "`hi_type'" == "oop" { ;
	local HI_OOP = 1 ;
} ;
else if "`hi_type'" == "tot" { ;
	local HI_TOT = 1 ;
} ;
else if "`hi_type'" == "oop_ratio_min" { ;
	local HI_OOP_RATIO_MIN = 1 ;
} ;
else if "`hi_type'" == "tot_ratio_min" { ;
	local HI_TOT_RATIO_MIN = 1 ;
} ;
else if "`hi_type'" == "fhl" { ;
	local HI_FHL_MAX = 1 ;
} ;

if "`earnings_responses'" == "baseline" { ;
	local FS_ESTIMATES_TYPE "diagnosis" ;
	local fs_scaling_factor = 1 ;
} ;
else if "`earnings_responses'" == "severity" { ;
	local FS_ESTIMATES_TYPE "severity" ;
	local fs_scaling_factor = 1 ;
} ;
else if "`earnings_responses'" == "multiplied_by_four" { ;
	local FS_ESTIMATES_TYPE "diagnosis" ;
	local fs_scaling_factor = 4 ;
} ;

if "`sdu'" == "none" { ;
	local sdu_str "" ;
} ;
else if "`sdu'" == "lower_when_more_severe" { ;
	local sdu_str "st25n" ;
} ;
else if "`sdu'" == "higher_when_more_severe" { ;
	local sdu_str "st25p" ;
} ;
global base_mu_var "floor_MU`crra'`sdu_str'_Nhls" ;

if "`severity_definition'" == "baseline" { ;
	local severe_definition "severe" ;
} ;
else if "`severity_definition'" == "plus_somewhat" { ;
	local severe_definition "severe2" ;
} ;
else if "`severity_definition'" == "plus_mental_health" { ;
	local severe_definition "severe_mhdp" ;
} ;

if "`risk_types_option'" == "baseline" { ;
	local risk_types "ed" ;
} ;
else if "`risk_types_option'" == "earnings" { ;
	local risk_types "z35d" ;
} ;
else if "`risk_types_option'" == "estimate_markup_with_controls" { ;
	local risk_types "reg" ;
} ;


/* ******************************* */
/* **** LOAD AND PREPARE DATA **** */
/* ******************************* */
local cash_ben                = 13000 ;
local di_et_thresh            = 1260*12 ;
local atr_for_fe              = 0.20 ;
local fe_pcf                  = 0.34 ;
local ben_increase_share      = 0.10 ;
local scaling_factor_award_cf = 0.1 ;

/* HI component */
if `HI_ZERO' == 1 { ;
	local hi_val_sev  = 0 ;
	local hi_val_ns   = 0 ;
	local hi_cost_sev = 0 ;
	local hi_cost_ns  = 0 ;
} ;
else if `HI_OOP' == 1 { ;
	local share_who_gain_hi_from_di = 0.25 ;
	local val_of_hi_as_share_of_net_cost = 0.85 ;
	local mean_oop_sev = 1471 ;
	local mean_oop_ns  =  521 ;
	local net_cost_per_full_hi_sev = `mean_oop_sev' ;
	local net_cost_per_full_hi_ns  =  `mean_oop_ns' ;
	local hi_cost_sev = `share_who_gain_hi_from_di' * `net_cost_per_full_hi_sev' ;
	local hi_cost_ns  = `share_who_gain_hi_from_di' * `net_cost_per_full_hi_ns'  ;
	local hi_val_sev  = `val_of_hi_as_share_of_net_cost' * `hi_cost_sev' ;
	local hi_val_ns   = `val_of_hi_as_share_of_net_cost' * `hi_cost_ns' ;
} ;
else if `HI_TOT' == 1 { ;
	local share_who_gain_hi_from_di = 0.25 ;
	local val_of_hi_as_share_of_net_cost = 0.85 ;
	local net_cost_share_of_tot = (1/5+1/3)/2 ;
	local mean_tot_sev = 20459 ;
	local mean_tot_ns  =  5662 ;
	local net_cost_per_full_hi_sev = `net_cost_share_of_tot' * `mean_tot_sev' ;
	local net_cost_per_full_hi_ns  = `net_cost_share_of_tot' *  `mean_tot_ns' ;
	local hi_cost_sev = `share_who_gain_hi_from_di' * `net_cost_per_full_hi_sev' ;
	local hi_cost_ns  = `share_who_gain_hi_from_di' * `net_cost_per_full_hi_ns'  ;
	local hi_val_sev  = `val_of_hi_as_share_of_net_cost' * `hi_cost_sev' ;
	local hi_val_ns   = `val_of_hi_as_share_of_net_cost' * `hi_cost_ns' ;
} ;
else if `HI_OOP_RATIO_MIN' == 1 { ;
	local share_who_gain_hi_from_di = 1.0 ;
	local val_of_hi_as_share_of_net_cost = 1.2 ;
	local mean_oop_sev = 1471 ;
	local mean_oop_ns  =  521 ;
	local net_cost_per_full_hi_sev = `mean_oop_sev' ;
	local net_cost_per_full_hi_ns  =  `mean_oop_ns' ;
	local hi_cost_sev = `share_who_gain_hi_from_di' * `net_cost_per_full_hi_sev' ;
	local hi_cost_ns  = `share_who_gain_hi_from_di' * `net_cost_per_full_hi_ns'  ;
	local hi_val_sev  = `val_of_hi_as_share_of_net_cost' * `hi_cost_sev' ;
	local hi_val_ns   = `val_of_hi_as_share_of_net_cost' * `hi_cost_ns' ;
} ;
else if `HI_TOT_RATIO_MIN' == 1 { ;
	local share_who_gain_hi_from_di = 1.0 ;
	local val_of_hi_as_share_of_net_cost = 1.2 ;
	local net_cost_share_of_tot = 1/3 ;
	local mean_tot_sev = 20459 ;
	local mean_tot_ns  =  5662 ;
	local net_cost_per_full_hi_sev = `net_cost_share_of_tot' * `mean_tot_sev' ;
	local net_cost_per_full_hi_ns  = `net_cost_share_of_tot' *  `mean_tot_ns' ;
	local hi_cost_sev = `share_who_gain_hi_from_di' * `net_cost_per_full_hi_sev' ;
	local hi_cost_ns  = `share_who_gain_hi_from_di' * `net_cost_per_full_hi_ns'  ;
	local hi_val_sev  = `val_of_hi_as_share_of_net_cost' * `hi_cost_sev' ;
	local hi_val_ns   = `val_of_hi_as_share_of_net_cost' * `hi_cost_ns' ;
} ;
else if `HI_FHL_MAX' == 1 { ;
	local share_who_gain_hi_from_di = 1.0 ;
	local hi_val_fhl  = 1675 ;
	local hi_cost_fhl = 1448 ;
	local hi_val_sev  = `hi_val_fhl'  ;
	local hi_cost_sev = `hi_cost_fhl' ;
	local hi_val_ns   = `hi_val_fhl'  ;
	local hi_cost_ns  = `hi_cost_fhl' ;
} ;
else { ;
	error ;
} ;
local ben_val_sev   = `cash_ben' + `hi_val_sev' ;
local ben_val_ns    = `cash_ben' + `hi_val_ns' ; 
local ben_cost_sev  = `cash_ben' + `hi_cost_sev' ; 
local ben_cost_ns   = `cash_ben' + `hi_cost_ns' ;
local wtp_ep_increase_ben = `cash_ben' * `ben_increase_share' ;

use "$temp/psid_hhlevel_forsummstats_dissi_`severe_definition'_2016.dta", clear ;

local base_mu_var "$base_mu_var" ;

if "`state_safety_net_quartile'" == "1" { ;
	keep if state_tanf17 == 1 ;
} ;
else if "`state_safety_net_quartile'" == "2" { ;
	keep if state_tanf17 == 2 ;
} ;
else if "`state_safety_net_quartile'" == "3" { ;
	keep if state_tanf17 == 3 ;
} ;
else if "`state_safety_net_quartile'" == "4" { ;
	keep if state_tanf17 == 4 ;
} ;

if `exclude_certain_ldi_benefits' == 1 { ;
	gen gp_new1 = (gp_di_ns == 1 & gp_sap == 1) ;
	gen gp_new2 = (gp_di_ns == 1 & (gp_predisev == 1 | gp_sap == 1)) ;
	gen gp_new3 = gp_di_ns_uifirst ;
	gen gp_new4 = max(gp_new3, gp_di_ns_jobshock) if ///
		(gp_new3 < . & gp_di_ns_jobshock < .) ;
	local num_ldi_het_types = 4 ;
	forvalues i = 1/`num_ldi_het_types' { ;
		gen gp_ex`i' = gp_ns_di - gp_new`i' ;
		gen gp_ldi`i' = gp_ns_di if gp_new`i' < . ;
	} ;
	local program_types "di ns_di" ;
	forvalues i = 1/`num_ldi_het_types' { ;
		local program_types "`program_types' ldi`i' ex`i' new`i'" ;
	} ;
} ;
else { ;
	gen gp_new = 1 ;
	gen gp_ex = 1 ;
	gen gp_ldi = 1 ;
} ;

drop if gp_sev == . ;
keep unique_id year flag_work_age head_age family_weight 
	flag_spouse diag_* inc_earn_HSP inc_earn_recip earnHSP35 gp_ui gp_ev
	gp_di gp_sev gp_mod gp_any gp_hsdrop gp_hsgrad gp_somecoll gp_college
	gp_pop gp_ndi gp_di_sev gp_di_ns gp_ndi_sev gp_ndi_ns gp_ns_di
	gp_sev_di gp_sev_ndi gp_ns_ndi gp_ns
	gp_adi gp_ad2 gp_ad3 gp_tdi gp_td2 gp_td3 `base_mu_var' inc_hh gp_all 
	gp_new* gp_ex* gp_ldi* inc_earn_head efficient_welfare_weight ;

gen gp_ie    = gp_ns_di ;
gen gp_award = gp_ns_di ;
gen gp_ben1  = gp_di ;

xtile z35decile = earnHSP35, nq(10) ;
forvalues i = 1/10 { ;
	gen gp_zd`i' = . ;
	replace gp_zd`i' = (z35decile == `i') if z35decile < . ;
} ;

rename gp_hsdrop gp_ed1 ;
rename gp_hsgrad gp_ed2 ;
rename gp_somecoll gp_ed3 ;
rename gp_college gp_ed4 ;


/* ************************************************************** */
/* **** CALCULATE EX POST WTP AND G FOR ALL TYPE-STATE-TIMES **** */
/* ************************************************************** */

gen_zndi_zdi_vars "$data" "`FS_ESTIMATES_TYPE'" `fs_scaling_factor' ;
drop diag* ;

replace z_di = `di_et_thresh' if gp_ndi == 1 & z_di > `di_et_thresh' & z_di < . ;
replace z_di = 0 if z_di < 0 ;

gen z_decrease_from_di = z_ndi - z_di ;
gen z_ndi_gtr_sga = . ;
replace z_ndi_gtr_sga = (z_ndi > `di_et_thresh') if z_ndi < . ;

gen delta = z_ndi_gtr_sga ;
gen wtp_ep = . ;
replace wtp_ep = (1 - delta) * `ben_val_sev' if gp_sev == 1 ;
replace wtp_ep = (1 - delta) * `ben_val_ns'  if gp_ns  == 1 ;

gen fe_dollars_ep_z = z_decrease_from_di * `atr_for_fe' ;
gen g_ep = . ;
replace g_ep = `ben_cost_sev' + fe_dollars_ep_z if gp_sev == 1 ;
replace g_ep = `ben_cost_ns'  + fe_dollars_ep_z if gp_ns  == 1 ;
gen me_dollars_ep = . ;
replace me_dollars_ep = `ben_val_sev' * (1-delta) if gp_sev == 1 ;
replace me_dollars_ep = `ben_val_ns'  * (1-delta) if gp_ns  == 1 ;


/* ******************************** */
/* ******* KEY CALCULATIONS ******* */
/* ******************************** */
local n_stats = 6 ;
local max_n_prog_types = 14 ;   /* Must be consistent w/ program_types */
local n_rows = `n_tot_risk_groups_incl_agg' * `max_n_prog_types' ;
matrix all_stats = J(`n_rows', `n_stats', .) ;
local row_num = 1 ;
local row_names "" ;
matrix key_stats = J(`max_n_prog_types', `n_stats', .) ;
local ks_row = 1 ;
local key_stats_row_names "" ;

rename `base_mu_var' mu ;

local pol_vars "" ;
foreach pol_type in ben award ie { ;
	foreach varstem in me_ea_per_ wtp_ea_in_N wtp_ea_in_g_per_ g_ea_per_ 
		ns_in_N ns_in_g_per_ { ;
		local pol_vars "`pol_vars' `varstem'rp_`pol_type' `varstem'p_`pol_type'" ;
	} ;
} ;
local add_drop_vars "mu_for_anal g_ea_per_rp g_ea_per_p me_ea_per_rp me_ea_per_p 
	wtp_ea_in_Nrp wtp_ea_in_Np wtp_ea_in_g_per_rp wtp_ea_in_g_per_p M ns_in_Nrp 
	ns_in_Np ns_in_g_per_rp ns_in_g_per_p ns_to_sbv_in_p 
	ns_stat_di_in_Nrp ns_to_sbv_stat_di_in_p wtp_for_ns_per_recip_calc 
	pr_i pi_rp_to_i pi_p_to_rp surp_in_rp_to_sbvp iow `pol_vars'" ;
local per_p_agg_di_cost_for_stat_di = -999 ;

matrix iow_mat = J(`num_risk_group_types', `max_num_real_risk_groups', .) ;
matrix emu_rp_over_emu_p_mat = J(`num_risk_group_types', `max_num_real_risk_groups', .) ;
matrix stat_di_z_mat = J(`num_risk_group_types', `max_num_real_risk_groups', .) ;
matrix stat_di_p_mat = J(`num_risk_group_types', `max_num_real_risk_groups', .) ;
matrix stat_di_r_mat = J(`num_risk_group_types', `max_num_real_risk_groups', .) ;
local risk_group_type_num = 1 ;

foreach risk_group_type in `risk_group_types' { ;
if "`risk_group_type'" == "sbv" | "`risk_group_type'" == "reg" { ;
	local risk_groups "all" ;
	local num_risk_groups = 1 ;
} ;
else if "`risk_group_type'" == "ed" { ;
	local risk_groups "ed1 ed2 ed3 ed4" ;
	local num_risk_groups = 4 ;
} ;
else if "`risk_group_type'" == "z35d" { ;
	local risk_groups "zd1 zd2 zd3 zd4 zd5 zd6 zd7 zd8 zd9 zd10" ;
	local num_risk_groups = 10 ;
} ;
else { ;
	BREAK ;
} ;

foreach varname in `add_drop_vars' { ;
	gen `varname' = . ;
} ;

foreach risk_group in `risk_groups' { ;
	if "`risk_group_type'" == "reg" { ;
		summ mu if gp_`risk_group' == 1 `weight_str' ;
		local emu_pop = r(mean) ;
		xtile inc_pct = inc_hh if gp_`risk_group' == 1 `weight_str', nq(4) ; 
		reg mu gp_ed1 gp_ed2 gp_ed3 gp_ed4 head_age flag_spouse i.inc_pct 
			if gp_`risk_group' == 1 `weight_str' ;
		predict double mu_residized, residuals ;
		drop inc_pct ;
		gen mu_predicted = . ;
		gen mu_purged = . ;
		replace mu_for_anal = max(0, mu_residized + `emu_pop') 
			if gp_`risk_group' == 1 & mu_residized != . ;
		replace mu_for_anal = max(0, mu_residized + `emu_pop') 
			if gp_`risk_group' == 1 & mu_residized != . ;
		drop mu_purged mu_predicted mu_residized ;
	} ;
	else { ;
		replace mu_for_anal = mu if gp_`risk_group' == 1 ;
	} ;
} ;

if "`risk_group_type'" != "sbv" { ;
	local risk_group_num = 1 ;
	local ea_expected_earnings = 0 ;
	foreach risk_group in `risk_groups' { ;
		if `risk_group_num' == 1 { ;
			summ gp_ndi if gp_`risk_group' != . `weight_str' ;
			local prob_p = r(mean) ;
			local per_cap_di_cost = `prob_p' * `per_p_agg_di_cost_for_stat_di' ;
		} ;
		gen gp_rp = . ;
		replace gp_rp = (gp_`risk_group' & gp_ndi) if gp_`risk_group' != . ;
		summ gp_rp if gp_`risk_group' != . `weight_str' ;
		local prob_rp = r(mean) ;
		matrix stat_di_p_mat[`risk_group_type_num', `risk_group_num'] = `prob_rp' ;
		summ z_indiv if gp_rp `weight_str' ;
		local mean_z = r(mean) ;
		matrix stat_di_z_mat[`risk_group_type_num', `risk_group_num'] = `mean_z' ;
		local ea_expected_earnings = `ea_expected_earnings' + `prob_rp' * `mean_z' ;
		drop gp_rp ;
		local risk_group_num = `risk_group_num' + 1 ;
	} ;
	local tau = `per_cap_di_cost' / `ea_expected_earnings' ;
	local risk_group_num = 1 ;
	foreach risk_group in `risk_groups' { ;
		matrix stat_di_r_mat[`risk_group_type_num', `risk_group_num'] = 
			`tau' * stat_di_z_mat[`risk_group_type_num', `risk_group_num'] ;
		local risk_group_num = `risk_group_num' + 1 ;
	} ;
} ;

local risk_group_num = 1 ;

foreach risk_group in `risk_groups' { ;

summ efficient_welfare_weight `weight_str' if gp_`risk_group' == 1 ;
matrix iow_mat[`risk_group_type_num', `risk_group_num'] = r(mean) ;
replace iow = iow_mat[`risk_group_type_num', `risk_group_num'] if gp_`risk_group' == 1 ;

local mvpf_r_tax_cut = 1 / iow_mat[`risk_group_type_num', `risk_group_num'] ;

summ gp_`risk_group' `weight_str' ;
local prob_risk_group = r(mean) ;
summ gp_ndi if gp_`risk_group' != . `weight_str' ;
local prob_p = r(mean) ;
gen gp_rp = . ;
replace gp_rp = (gp_`risk_group' & gp_ndi) if gp_`risk_group' != . ;
summ gp_rp if gp_`risk_group' != . `weight_str' ;
local prob_rp = r(mean) ;
drop gp_rp ;
gen gp_rdi = . ;
replace gp_rdi = (gp_`risk_group' & gp_di) if gp_`risk_group' != . ;
summ gp_rdi if gp_`risk_group' != . `weight_str' ;
local prob_rdi = r(mean) ;
drop gp_rdi ;
sum gp_pop if gp_`risk_group' != . `weight_str' ;
local n_pop = r(sum_w) ;
replace pr_i = family_weight / `n_pop' if gp_`risk_group' == 1 ;

replace pi_rp_to_i = pr_i / `prob_rp' if gp_`risk_group' == 1 ;
replace pi_p_to_rp = `prob_rp' / `prob_p' if gp_`risk_group' == 1 ;

summ mu_for_anal if gp_`risk_group' == 1 & gp_ndi == 1 `weight_str' ;
local emu_rp = r(mean) ;
summ mu_for_anal if gp_`risk_group' != . & gp_ndi == 1 `weight_str' ;
local emu_p = r(mean) ;
matrix emu_rp_over_emu_p_mat[`risk_group_type_num', `risk_group_num'] = 
	`emu_rp' / `emu_p' ;

replace surp_in_rp_to_sbvp = pi_p_to_rp * (`emu_rp' / `emu_p') if gp_`risk_group' == 1 ;
local surp_in_rp_to_sbvp = (`prob_rp' / `prob_p') * (`emu_rp' / `emu_p') ;

replace g_ea_per_rp  = pi_rp_to_i * g_ep          if gp_`risk_group' == 1 ;
replace me_ea_per_rp = pi_rp_to_i * me_dollars_ep if gp_`risk_group' == 1 ;

replace mu_for_anal = mu_for_anal * (1-`discount_on_ldi_benefits') if 
	gp_ns_di == 1 & gp_`risk_group' == 1 ;

replace M = mu_for_anal / `emu_rp' - 1 if gp_`risk_group' == 1 ;
replace M = `markup_scaling_factor' * M if gp_`risk_group' == 1 ;

replace wtp_ea_in_Nrp = pi_rp_to_i * (1 + M) * wtp_ep if gp_`risk_group' == 1 ;
replace wtp_ea_in_g_per_rp = wtp_ea_in_Nrp * iow if gp_`risk_group' == 1 ;

replace wtp_for_ns_per_recip_calc = (1 + M) * wtp_ep * iow if gp_`risk_group' == 1 ;

replace ns_in_Nrp = wtp_ea_in_Nrp - g_ea_per_rp / iow   if gp_`risk_group' == 1 ;		
replace ns_in_g_per_rp = ns_in_Nrp * iow                if gp_`risk_group' == 1 ;

if "`risk_group_type'" != "sbv" { ;
	local per_rp_net_gov_rev = stat_di_r_mat[`risk_group_type_num', `risk_group_num'] ;
	local per_rdi_net_gov_rev = `prob_rp' * `per_rp_net_gov_rev' / `prob_rdi' ;
	replace ns_stat_di_in_Nrp = wtp_ea_in_Nrp - `per_rdi_net_gov_rev' * pi_rp_to_i / iow
		if gp_`risk_group' == 1 & gp_di == 1 ;
	replace ns_to_sbv_stat_di_in_p = ns_stat_di_in_Nrp * surp_in_rp_to_sbvp
		if gp_`risk_group' == 1 & gp_di == 1 ;
} ;

replace ns_to_sbv_in_p  = ns_in_Nrp  * surp_in_rp_to_sbvp if gp_`risk_group' == 1 ;

replace me_ea_per_rp_ben = 
	pi_rp_to_i * `wtp_ep_increase_ben' if gp_`risk_group' == 1 ;
replace wtp_ea_in_Nrp_ben = 
	pi_rp_to_i * (1 + M) * `wtp_ep_increase_ben' if gp_`risk_group' == 1 ;
replace wtp_ea_in_g_per_rp_ben = 
	wtp_ea_in_Nrp_ben * iow if gp_`risk_group' == 1 ;
replace me_ea_per_rp_award = 
	me_ea_per_rp * `scaling_factor_award_cf' if gp_`risk_group' == 1 ;
replace wtp_ea_in_Nrp_award = 
	wtp_ea_in_Nrp * `scaling_factor_award_cf' if gp_`risk_group' == 1 ;
replace wtp_ea_in_g_per_rp_award = 
	wtp_ea_in_g_per_rp * `scaling_factor_award_cf' if gp_`risk_group' == 1 ;
replace me_ea_per_rp_ie = me_ea_per_rp if gp_`risk_group' == 1 ;
replace wtp_ea_in_Nrp_ie = wtp_ea_in_Nrp if gp_`risk_group' == 1 ;
replace wtp_ea_in_g_per_rp_ie = wtp_ea_in_g_per_rp if gp_`risk_group' == 1 ;
foreach pol in ben award ie { ;
	replace g_ea_per_rp_`pol' = 
		me_ea_per_rp_`pol' * (1 + `fe_pcf') if gp_`risk_group' == 1 ;
	replace ns_in_Nrp_`pol' = 
		wtp_ea_in_Nrp_`pol' - g_ea_per_rp_`pol' / iow if gp_`risk_group' == 1 ;
	replace ns_in_g_per_rp_`pol' = 
		ns_in_Nrp_`pol' * iow if gp_`risk_group' == 1 ;
} ;

foreach varstem in me_ea g_ea wtp_ea_in_g ns_in_g { ;
	replace `varstem'_per_p = `varstem'_per_rp * pi_p_to_rp if gp_`risk_group' == 1 ;
} ;
foreach varstem in wtp_ea ns { ;
	replace `varstem'_in_Np = `varstem'_in_Nrp * pi_p_to_rp if gp_`risk_group' == 1 ;
} ;
foreach pol in ben award ie { ;
	foreach varstem in me_ea_per_ wtp_ea_in_N wtp_ea_in_g_per_ g_ea_per_ 
		ns_in_N ns_in_g_per_ { ;
		replace `varstem'p_`pol' = 
			`varstem'rp_`pol' * pi_p_to_rp if gp_`risk_group' == 1 ;
	} ;
} ;

if "`risk_group_type'" == "sbv" | "`risk_group_type'" == "reg" | 
	`risk_group_num' < `num_risk_groups' { ;
	local pops_this_loop "`risk_group'" ;
} ;
else { ;
	local pops_this_loop "`risk_group' pop" ;
} ;

foreach pop in `pops_this_loop' { ;
foreach prog in `program_types' { ;
	local row_names "`row_names' `pop'_`prog'" ;
	
	local ifcond "if gp_`pop' == 1 & gp_`prog' == 1 & gp_`risk_group' != . " ;
	if "`risk_group_type'" == "reg" { ;
		local ifcond "`ifcond' & mu_for_anal != . " ;
	} ;
	
	sum ns_to_sbv_in_p `ifcond' ;
	local ns_to_sbv_in_p = r(sum) ;
	sum ns_to_sbv_stat_di_in_p `ifcond' ;
	local ns_sbv_stat_di = r(sum) ;
	
	if "`pop'" != "pop" { ;
		local per_str "rp" ;
	} ;
	else if "`pop'" == "pop" { ;
		local per_str "p" ;
		local prob_risk_group = 1 ;
	} ;
	sum g_ea_per_`per_str' `ifcond' ;
	local g_agg = r(sum) ;
	sum wtp_ea_in_N`per_str' `ifcond' ;
	local wtp_agg = r(sum) ;
	sum ns_in_g_per_`per_str' `ifcond' ;
	local ns_in_g = r(sum) ;
	
	if "`prog'" == "ie" | "`prog'" == "ben" | "`prog'" == "award" { ;
		sum wtp_ea_in_N`per_str'_`prog' `ifcond' ;
		local wtp_agg = r(sum) ;
		sum g_ea_per_`per_str'_`prog' `ifcond' ;
		local g_agg = r(sum) ;
		sum ns_in_g_per_`per_str'_`prog' `ifcond' ;
		local ns_in_g = r(sum) ;
		local ns_to_sbv_in_p     = `missing_val_code' ;
		local ns_sbv_stat_di     = `missing_val_code' ;
	} ;
	
	local mvpf_agg = `wtp_agg' / `g_agg' ;
	
	sum gp_`prog' if gp_`pop' == 1 & gp_`risk_group' != . `weight_str' ;
	local recip_rate = r(mean) ;
	if "`prog'" == "award" { ;
		local recip_rate = `recip_rate' * `scaling_factor_award_cf' ;
	} ;
	
	sum gp_ndi if gp_`pop' == 1 & gp_`risk_group' != . `weight_str' ;
	local payer_share = r(mean) ;
	
	sum M `ifcond' `weight_str' ;
	local mean_markup = r(mean) ;
	
	sum z_ndi `ifcond' `weight_str' ;
	local mean_zndi = r(mean) ;
	
	matrix all_stats[`row_num', 1]  = `mean_markup' ;
	matrix all_stats[`row_num', 2]  = `mean_zndi' ;
	matrix all_stats[`row_num', 3]  = `ns_in_g' * `payer_share' ;
	matrix all_stats[`row_num', 4]  = `ns_in_g' * `payer_share' / `recip_rate' ;
	matrix all_stats[`row_num', 5]  = (`ns_in_g' + `g_agg') / `g_agg' ;
	matrix all_stats[`row_num', 6]  = `mvpf_agg' ;
	
	if "`risk_group_type'" == "`risk_types'" & 
		("`pop'" == "pop" | "`pop'" == "all") { ;
		local key_stats_row_names "`key_stats_row_names' `prog'" ;
		matrix key_stats[`ks_row', 1] = all_stats[`row_num', 1..`n_stats'] ;
		local ks_row = `ks_row' + 1 ;
		if "`prog'" == "di" { ;
			local sbv_surp_per_hh_no_redist = 
				`ns_to_sbv_in_p' * `prob_p' / `prob_risk_group' ;
			local sbv_surp_per_hh_redist = 
				`ns_sbv_stat_di' * `prob_p' / `prob_risk_group' ;
		} ;
	} ;
	
	if "`risk_group_type'" == "sbv" & "`prog'" == "di" { ;
		local per_p_agg_di_cost_for_stat_di = `g_agg' ;
	} ;
	
	local row_num = `row_num' + 1 ;
	
} ; /* Ends loop over program_types */
} ; /* Ends loop over pops_this_loop */

local risk_group_num = `risk_group_num' + 1 ;

} ; /* Ends loop over risk_groups */

if "`risk_group_type'" == "`risk_types'" { ;
	gen M_base = M ;
	gen g_per_p_base = g_ea_per_p ;
	gen wtp_per_p_base = wtp_ea_in_Np ;
	gen ns_per_p_base = ns_in_g_per_p ;
	gen ns_to_sbv_per_p_base = ns_to_sbv_in_p ;
	gen g_per_recip_base = g_ep ;
	gen wtp_per_recip_base = wtp_ep * (1 + M_base) ;
	gen ns_per_recip_base = wtp_for_ns_per_recip_calc - g_per_recip_base ;
} ;

drop `add_drop_vars' ;

local risk_group_type_num = `risk_group_type_num' + 1 ;

} ;         /* Ends loop over risk_group_types */

local col_names "Mean_markup Cf_earnings Surp_per_hh Surp_per_recip" ;
local col_names "`col_names' Val_rel_to_cost_eq_tax_cut MVPF" ;
matrix rownames all_stats = `row_names' ;
matrix colnames all_stats = `col_names' ;
matrix rownames key_stats = `key_stats_row_names' ;
matrix colnames key_stats = `col_names' ;


/* ********************* */
/* ****** FIGURES ****** */
/* ********************* */

replace family_weight = 1e-5 if family_weight == 0 ;
/* Necessary to properly sum the per-P variables in the following
collapse.  These variables already reflect weights, so we need to 
collapse using rawsum rather than sum, and rawsum excludes observations 
with a weight of zero. */

foreach gp in di sev_di ns_di ndi sev_ndi ns_ndi pop sev ns { ;
    preserve ;
    keep if gp_`gp' == 1 ;
    gen count = 1 ;
    collapse
        (mean) gp_sev M_* z_ndi g_per_recip_base 
			wtp_per_recip_base ns_per_recip_base
		(rawsum) g_per_p_base wtp_per_p_base 
			ns_per_p_base ns_to_sbv_per_p_base
        (count) count
        `weight_str'
        ;
    tempfile gp_`gp' ;
    save `gp_`gp'' ;
    restore ;
} ;

use `gp_di', clear ;
gen gp = "`gp'" ;
foreach gp in di sev_di ns_di ndi sev_ndi ns_ndi pop sev ns { ;
    append using `gp_`gp'' ;
    replace gp = "`gp'" if gp == "" ;
} ;
drop if _n == 1 ;
rename gp_sev frac_sev ;
order gp ;

foreach gp in di sev_di ns_di ndi sev_ndi ns_ndi pop sev ns { ;
    gen byte gp_`gp' = (gp == "`gp'") ;
} ;
expand 2 ;

foreach var of varlist frac_sev z_ndi g_per_p_base g_per_recip_base { ;
	replace `var' = . if _n>(_N/2) ;
} ;

recode gp_ns_di (1=0) (0=1) if frac_sev == . ;    
recode gp_ns_ndi (1=0) (0=1) if frac_sev == . ;    
recode gp_sev_di (1=0) (0=1) if frac_sev == . ;    
recode gp_sev_ndi (1=0) (0=1) if frac_sev == . ;
recode gp_pop (1=0) (0=1) if frac_sev == . ;
recode gp_di (1=0) (0=1) if frac_sev == . ;

replace gp = "L-DI" if gp == "ns_di" ;
replace gp = "L-NDI" if gp == "ns_ndi" ;
replace gp = "M-DI" if gp == "sev_di" ;
replace gp = "M-NDI" if gp == "sev_ndi" ;
replace gp = "DI" if gp == "di" ;
replace gp = "NDI" if gp == "ndi" ;
replace gp = "M" if gp == "sev" ;
replace gp = "L" if gp == "ns" ;
replace gp = "M" if gp == "sev" ;
replace gp = "Pop" if gp == "pop" ;

twoway     
	(scatter ns_per_recip_base frac_sev if (gp_ns_di==1), msymbol(none) mlabel(gp) mlabposition(12) mlabcolor(black))
	(scatter ns_per_recip_base frac_sev if (gp_ns_di==1) [aw=count], msymbol(Oh) mcolor(blue))
	(scatter ns_per_recip_base frac_sev if (gp_ns_ndi==1), msymbol(none) mlabel(gp) mlabposition(6) mlabcolor(black))
	(scatter ns_per_recip_base frac_sev if (gp_ns_ndi==1) [aw=count], msymbol(Oh) mcolor(ltblue))
	(scatter ns_per_recip_base frac_sev if (gp_sev_di==1), msymbol(none) mlabel(gp) mlabposition(12) mlabcolor(black))
	(scatter ns_per_recip_base frac_sev if (gp_sev_di==1) [aw=count], msymbol(Oh) mcolor(pink*1.5))
	(scatter ns_per_recip_base frac_sev if (gp_sev_ndi==1), msymbol(none) mlabel(gp) mlabposition(12) mlabcolor(black))
	(scatter ns_per_recip_base frac_sev if (gp_sev_ndi==1) [aw=count], msymbol(Oh) mcolor(pink*.5))
	(scatter ns_per_recip_base frac_sev if (gp_pop==1), msymbol(none) mlabel(gp) mlabposition(12) mlabcolor(black))
	(scatter ns_per_recip_base frac_sev if (gp_pop==1) [aw=count], msymbol(Oh) mcolor(gray))
	(scatter ns_per_recip_base frac_sev if (gp_di==1), msymbol(none) mlabel(gp) mlabposition(12) mlabcolor(black))
	(scatter ns_per_recip_base frac_sev if (gp_di==1) [aw=count], msymbol(Oh) mcolor(purple))
		,
		legend(off)
		xtitle("Fraction severe", size(medsmall))
		ytitle("Surplus per recipient ($)", size(medsmall))
		/* ysc(r(0 3)) ylab(0(.5)3)
		xsc(r(-.05 1.05)) xlab(0(.2)1) */
		yline(0, lcolor(gray*.5))
		graphregion(color(white))
		bgcolor(white)
		ylabel(,nogrid)
		;    
	graph export  "$output/norm_fig1_surp_vs_sev.pdf", replace;

local M_var "M_base" ;
twoway     
	(scatter `M_var' z_ndi if (gp_ns_di==1), msymbol(none) mlabel(gp) mlabposition(2) mlabcolor(black))
	(scatter `M_var' z_ndi if (gp_ns_di==1) [aw=count], msymbol(Oh) mcolor(blue))
	(scatter `M_var' z_ndi if (gp_ns_ndi==1), msymbol(none) mlabel(gp) mlabposition(6) mlabcolor(black))
	(scatter `M_var' z_ndi if (gp_ns_ndi==1) [aw=count], msymbol(Oh) mcolor(ltblue))
	(scatter `M_var' z_ndi if (gp_sev_di==1), msymbol(none) mlabel(gp) mlabposition(11) mlabcolor(black))
	(scatter `M_var' z_ndi if (gp_sev_di==1) [aw=count], msymbol(Oh) mcolor(pink*1.5))
	(scatter `M_var' z_ndi if (gp_sev_ndi==1), msymbol(none) mlabel(gp) mlabposition(12) mlabcolor(black))
	(scatter `M_var' z_ndi if (gp_sev_ndi==1) [aw=count], msymbol(Oh) mcolor(pink*.5))
	(scatter `M_var' z_ndi if (gp_pop==1), msymbol(none) mlabel(gp) mlabposition(12) mlabcolor(black))
	(scatter `M_var' z_ndi if (gp_pop==1) [aw=count], msymbol(Oh) mcolor(gray))
	(scatter `M_var' z_ndi if (gp_di==1), msymbol(none) mlabel(gp) mlabposition(12) mlabcolor(black))
	(scatter `M_var' z_ndi if (gp_di==1) [aw=count], msymbol(Oh) mcolor(purple))
		,
		legend(off)
		xtitle("Counterfactual no-DI annual earnings ($)", size(medsmall))
		ytitle("Markup", size(medsmall))
		ysc(r(-.5 1)) ylab(-.5(.5)1)
		xsc(r(-1000 61000)) xlab(0(20000)60000)
		yline(0, lcolor(gray*.5))
		graphregion(color(white))
		bgcolor(white)
		ylabel(,nogrid)
		;    
	graph export  "$output/norm_fig2_M_vs_zndi.pdf", replace;


* Display key results for table and text ;
if `exclude_certain_ldi_benefits' == 0 { ;
	matrix list key_stats ;
	di "Proportional increase in value of DI to someone behind veil from redist =" 
		(`sbv_surp_per_hh_redist' - `sbv_surp_per_hh_no_redist') / 
		`sbv_surp_per_hh_redist' ;
} ;
else { ;
	forvalues i = 1/4 { ;
		local row = 3 + (`i'-1)*3 ;
		local ldi_het`i' = 1 - key_stats[`row'+1,3]/key_stats[`row',3] ;
	} ;
	di "Proportional decrease in surplus from L-DI from excluding... " ;
	di "... L-DI who were more-severe when first received DI =" `ldi_het1' ;
	di "... L-DI who were more-severe before or when first received DI =" `ldi_het2' ;
	di "... L-DI who received UI=" `ldi_het3' ;
	di "... L-DI who received UI or lost job =" `ldi_het4' ;
} ;
if `by_ed_het' == 1 { ;
	matrix ed_results = all_stats["ed1_di".."ed4_award", 1..6] ;
	matrix list ed_results ;
} ;

log close ;
